@@ -126,7 +126,7 @@ fn ensure_tag_is_greater_than_previous(current: &Tag, next: &Tag) -> Result<()>
         let comparison = format!("{current} <= {next}").red();
         let cause_key = "cause:".red();
         let cause = format!("{cause_key} version MUST be greater than current one: {comparison}");
-        bail!("{}:\n\t{}\n", "SemVer Error".red().to_string(), cause);
+        bail!("{}:\n\t{}\n", "SemVer Error".red(), cause);
     };
 
     Ok(())
@@ -212,7 +212,11 @@ impl CocoGitto {
     }
 
     /// The target version is not created yet when generating the changelog.
-    pub fn get_changelog_with_target_version(&self, pattern: &str, tag: Tag) -> Result<Release> {
+    pub fn get_changelog_with_target_version(
+        &self,
+        pattern: &str,
+        tag: Tag,
+    ) -> Result<Release<'_>> {
         let commit_range = self.repository.revwalk(pattern)?;
         let mut release = Release::try_from(commit_range)?;
         release.version = OidOf::Tag(tag);
@@ -225,7 +229,7 @@ impl CocoGitto {
         pattern: &str,
         tag: Tag,
         package: &str,
-    ) -> Result<Release> {
+    ) -> Result<Release<'_>> {
         let commit_range = self
             .repository
             .get_commit_range_for_package(pattern, package)?;
@@ -241,7 +245,7 @@ impl CocoGitto {
         pattern: &str,
         from: OidOf,
         tag: Tag,
-    ) -> Result<Release> {
+    ) -> Result<Release<'_>> {
         let commit_range = self
             .repository
             .get_commit_range_for_monorepo_global(pattern)?;
