@@ -135,6 +135,7 @@ mod test {
     use conventional_commit_parser::commit::{CommitType, ConventionalCommit, Footer};
     use git2::Oid;
     use indoc::indoc;
+    use itertools::Itertools;
     use pretty_assertions::assert_eq;
     use speculoos::prelude::*;
 
@@ -149,6 +150,15 @@ mod test {
 
     use crate::git::tag::Tag;
 
+    macro_rules! assert_doc_eq {
+        ($changelog:expr, $doc:literal) => {
+            assert_eq!(
+                $changelog.split('\n').map(|line| line.trim()).join("\n"),
+                indoc!($doc).split('\n').map(|line| line.trim()).join("\n")
+            )
+        };
+    }
+
     #[test]
     fn should_get_a_release() -> anyhow::Result<()> {
         let repo = Repository::open(".")?;
@@ -170,17 +180,15 @@ mod test {
         let changelog = renderer.render(release)?;
 
         // Assert
-        assert_eq!(
+        assert_doc_eq!(
             changelog,
-            indoc! {
-                "## 1.0.0 - 2015-09-05
-                #### Bug Fixes
-                - **(parser)** fix parser implementation - (17f7e23) - *oknozor*
-                #### Features
-                - **(parser)** implement the changelog generator - (17f7e23) - *oknozor*
-                - awesome feature - (17f7e23) - Paul Delafosse
-                "
-            }
+            "## 1.0.0 - 2015-09-05
+            #### Features
+            - (**parser**) implement the changelog generator - (17f7e23) - *oknozor*
+            - awesome feature - (17f7e23) - Paul Delafosse
+            #### Bug Fixes
+            - (**parser**) fix parser implementation - (17f7e23) - *oknozor*
+            "
         );
 
         Ok(())
@@ -199,17 +207,15 @@ mod test {
         let changelog = renderer.render(release)?;
 
         // Assert
-        assert_eq!(
+        assert_doc_eq!(
             changelog,
-            indoc! {
-                "#### Bug Fixes
-                - 17f7e23081db15e9318aeb37529b1d473cf41cbe - **(parser)** fix parser implementation - @oknozor
-                #### Features
-                - 17f7e23081db15e9318aeb37529b1d473cf41cbe - **(parser)** implement the changelog generator - @oknozor
-                - 17f7e23081db15e9318aeb37529b1d473cf41cbe - awesome feature - Paul Delafosse
+            "#### Features
+            - 17f7e23081db15e9318aeb37529b1d473cf41cbe - (**parser**) implement the changelog generator - @oknozor
+            - 17f7e23081db15e9318aeb37529b1d473cf41cbe - awesome feature - Paul Delafosse
 
-                "
-            }
+            #### Bug Fixes
+            - 17f7e23081db15e9318aeb37529b1d473cf41cbe - (**parser**) fix parser implementation - @oknozor
+            "
         );
 
         Ok(())
@@ -232,17 +238,15 @@ mod test {
         let changelog = renderer.render(release)?;
 
         // Assert
-        assert_eq!(
+        assert_doc_eq!(
             changelog,
-            indoc! {
-                "## [1.0.0](https://github.com/cocogitto/cocogitto/compare/0.1.0..1.0.0) - 2015-09-05
-                #### Bug Fixes
-                - **(parser)** fix parser implementation - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
-                #### Features
-                - **(parser)** implement the changelog generator - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
-                - awesome feature - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - Paul Delafosse
-                "
-            }
+            "## [1.0.0](https://github.com/cocogitto/cocogitto/compare/0.1.0..1.0.0) - 2015-09-05
+            #### Features
+            - (**parser**) implement the changelog generator - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
+            - awesome feature - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - Paul Delafosse
+            #### Bug Fixes
+            - (**parser**) fix parser implementation - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
+            "
         );
 
         Ok(())
@@ -263,21 +267,19 @@ mod test {
         let changelog = renderer.render(release)?;
 
         // Assert
-        assert_eq!(
+        assert_doc_eq!(
             changelog,
-            indoc! {
-                "## 1.0.0 - 2015-09-05
-                ### Package updates
-                - one bumped to 0.1.0
-                - two bumped to 0.2.0
-                ### Global changes
-                #### Bug Fixes
-                - **(parser)** fix parser implementation - (17f7e23) - *oknozor*
-                #### Features
-                - **(parser)** implement the changelog generator - (17f7e23) - *oknozor*
-                - awesome feature - (17f7e23) - Paul Delafosse
-                "
-            }
+            "## 1.0.0 - 2015-09-05
+            ### Package updates
+            - one bumped to 0.1.0
+            - two bumped to 0.2.0
+            ### Global changes
+            #### Features
+            - (**parser**) implement the changelog generator - (17f7e23) - *oknozor*
+            - awesome feature - (17f7e23) - Paul Delafosse
+            #### Bug Fixes
+            - (**parser**) fix parser implementation - (17f7e23) - *oknozor*
+            "
         );
 
         Ok(())
@@ -292,27 +294,25 @@ mod test {
             kind: TemplateKind::MonorepoDefault,
         })?;
 
-        let mut renderer = monorepo_manual_bump_rendered(renderer)?;
+        let mut renderer = monorepo_manual_bump_renderer(renderer)?;
 
         // Act
         let changelog = renderer.render(release)?;
 
         // Assert
-        assert_eq!(
+        assert_doc_eq!(
             changelog,
-            indoc! {
-                "## 1.0.0 - 2015-09-05
-                ### Packages
-                - one locked to 0.1.0
-                - two locked to 0.2.0
-                ### Global changes
-                #### Bug Fixes
-                - **(parser)** fix parser implementation - (17f7e23) - *oknozor*
-                #### Features
-                - **(parser)** implement the changelog generator - (17f7e23) - *oknozor*
-                - awesome feature - (17f7e23) - Paul Delafosse
-                "
-            }
+            "## 1.0.0 - 2015-09-05
+            ### Packages
+            - one locked to 0.1.0
+            - two locked to 0.2.0
+            ### Global changes
+            #### Features
+            - (**parser**) implement the changelog generator - (17f7e23) - *oknozor*
+            - awesome feature - (17f7e23) - Paul Delafosse
+            #### Bug Fixes
+            - (**parser**) fix parser implementation - (17f7e23) - *oknozor*
+            "
         );
 
         Ok(())
@@ -333,21 +333,19 @@ mod test {
         let changelog = renderer.render(release)?;
 
         // Assert
-        assert_eq!(
+        assert_doc_eq!(
             changelog,
-            indoc! {
-                "### Package updates
-                - one bumped to 0.1.0
-                - two bumped to 0.2.0
-                ### Global changes
-                #### Bug Fixes
-                - 17f7e23081db15e9318aeb37529b1d473cf41cbe - **(parser)** fix parser implementation - @oknozor
-                #### Features
-                - 17f7e23081db15e9318aeb37529b1d473cf41cbe - **(parser)** implement the changelog generator - @oknozor
-                - 17f7e23081db15e9318aeb37529b1d473cf41cbe - awesome feature - Paul Delafosse
+            "### Package updates
+            - one bumped to 0.1.0
+            - two bumped to 0.2.0
+            ### Global changes
+            #### Features
+            - 17f7e23081db15e9318aeb37529b1d473cf41cbe - (**parser**) implement the changelog generator - @oknozor
+            - 17f7e23081db15e9318aeb37529b1d473cf41cbe - awesome feature - Paul Delafosse
 
-                "
-            }
+            #### Bug Fixes
+            - 17f7e23081db15e9318aeb37529b1d473cf41cbe - (**parser**) fix parser implementation - @oknozor
+            "
         );
 
         Ok(())
@@ -362,27 +360,25 @@ mod test {
             kind: TemplateKind::MonorepoFullHash,
         })?;
 
-        let mut renderer = monorepo_manual_bump_rendered(renderer)?;
+        let mut renderer = monorepo_manual_bump_renderer(renderer)?;
 
         // Act
         let changelog = renderer.render(release)?;
 
         // Assert
-        assert_eq!(
+        assert_doc_eq!(
             changelog,
-            indoc! {
-                "### Packages
-                - one locked to 0.1.0
-                - two locked to 0.2.0
-                ### Global changes
-                #### Bug Fixes
-                - 17f7e23081db15e9318aeb37529b1d473cf41cbe - **(parser)** fix parser implementation - @oknozor
-                #### Features
-                - 17f7e23081db15e9318aeb37529b1d473cf41cbe - **(parser)** implement the changelog generator - @oknozor
-                - 17f7e23081db15e9318aeb37529b1d473cf41cbe - awesome feature - Paul Delafosse
+            "### Packages
+            - one locked to 0.1.0
+            - two locked to 0.2.0
+            ### Global changes
+            #### Features
+            - 17f7e23081db15e9318aeb37529b1d473cf41cbe - (**parser**) implement the changelog generator - @oknozor
+            - 17f7e23081db15e9318aeb37529b1d473cf41cbe - awesome feature - Paul Delafosse
 
-                "
-            }
+            #### Bug Fixes
+            - 17f7e23081db15e9318aeb37529b1d473cf41cbe - (**parser**) fix parser implementation - @oknozor
+            "
         );
 
         Ok(())
@@ -407,21 +403,19 @@ mod test {
         let changelog = renderer.render(release)?;
 
         // Assert
-        assert_eq!(
+        assert_doc_eq!(
             changelog,
-            indoc! {
-                "## [1.0.0](https://github.com/cocogitto/cocogitto/compare/0.1.0..1.0.0) - 2015-09-05
-                ### Package updates
-                - [0.1.0](crates/one) bumped to [0.1.0](https://github.com/cocogitto/cocogitto/compare/0.2.0..0.1.0)
-                - [0.2.0](crates/two) bumped to [0.2.0](https://github.com/cocogitto/cocogitto/compare/0.3.0..0.2.0)
-                ### Global changes
-                #### Bug Fixes
-                - **(parser)** fix parser implementation - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
-                #### Features
-                - **(parser)** implement the changelog generator - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
-                - awesome feature - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - Paul Delafosse
-                "
-            }
+            "## [1.0.0](https://github.com/cocogitto/cocogitto/compare/0.1.0..1.0.0) - 2015-09-05
+            ### Package updates
+            - [0.1.0](crates/one) bumped to [0.1.0](https://github.com/cocogitto/cocogitto/compare/0.2.0..0.1.0)
+            - [0.2.0](crates/two) bumped to [0.2.0](https://github.com/cocogitto/cocogitto/compare/0.3.0..0.2.0)
+            ### Global changes
+            #### Features
+            - (**parser**) implement the changelog generator - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
+            - awesome feature - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - Paul Delafosse
+            #### Bug Fixes
+            - (**parser**) fix parser implementation - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
+            "
         );
 
         Ok(())
@@ -442,17 +436,15 @@ mod test {
         let changelog = renderer.render(release)?;
 
         // Assert
-        assert_eq!(
+        assert_doc_eq!(
             changelog,
-            indoc! {
-                "## 1.0.0 - 2015-09-05
-                #### Bug Fixes
-                - **(parser)** fix parser implementation - (17f7e23) - *oknozor*
-                #### Features
-                - **(parser)** implement the changelog generator - (17f7e23) - *oknozor*
-                - awesome feature - (17f7e23) - Paul Delafosse
-                "
-            }
+            "## 1.0.0 - 2015-09-05
+            #### Features
+            - (**parser**) implement the changelog generator - (17f7e23) - *oknozor*
+            - awesome feature - (17f7e23) - Paul Delafosse
+            #### Bug Fixes
+            - (**parser**) fix parser implementation - (17f7e23) - *oknozor*
+            "
         );
 
         Ok(())
@@ -473,17 +465,15 @@ mod test {
         let changelog = renderer.render(release)?;
 
         // Assert
-        assert_eq!(
+        assert_doc_eq!(
             changelog,
-            indoc! {
-                "#### Bug Fixes
-                - 17f7e23081db15e9318aeb37529b1d473cf41cbe - **(parser)** fix parser implementation - @oknozor
-                #### Features
-                - 17f7e23081db15e9318aeb37529b1d473cf41cbe - **(parser)** implement the changelog generator - @oknozor
-                - 17f7e23081db15e9318aeb37529b1d473cf41cbe - awesome feature - Paul Delafosse
+            "#### Features
+            - 17f7e23081db15e9318aeb37529b1d473cf41cbe - (**parser**) implement the changelog generator - @oknozor
+            - 17f7e23081db15e9318aeb37529b1d473cf41cbe - awesome feature - Paul Delafosse
 
-                "
-            }
+            #### Bug Fixes
+            - 17f7e23081db15e9318aeb37529b1d473cf41cbe - (**parser**) fix parser implementation - @oknozor
+            "
         );
 
         Ok(())
@@ -508,17 +498,15 @@ mod test {
         let changelog = renderer.render(release)?;
 
         // Assert
-        assert_eq!(
+        assert_doc_eq!(
             changelog,
-            indoc! {
-                "## [1.0.0](https://github.com/cocogitto/cocogitto/compare/0.1.0..1.0.0) - 2015-09-05
-                #### Bug Fixes
-                - **(parser)** fix parser implementation - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
-                #### Features
-                - **(parser)** implement the changelog generator - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
-                - awesome feature - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - Paul Delafosse
-                "
-            }
+            "## [1.0.0](https://github.com/cocogitto/cocogitto/compare/0.1.0..1.0.0) - 2015-09-05
+            #### Features
+            - (**parser**) implement the changelog generator - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
+            - awesome feature - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - Paul Delafosse
+            #### Bug Fixes
+            - (**parser**) fix parser implementation - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
+            "
         );
 
         Ok(())
@@ -537,27 +525,25 @@ mod test {
             kind: TemplateKind::MonorepoRemote,
         })?;
 
-        let mut renderer = monorepo_manual_bump_rendered(renderer)?;
+        let mut renderer = monorepo_manual_bump_renderer(renderer)?;
 
         // Act
         let changelog = renderer.render(release)?;
 
         // Assert
-        assert_eq!(
+        assert_doc_eq!(
             changelog,
-            indoc! {
-                "## [1.0.0](https://github.com/cocogitto/cocogitto/compare/0.1.0..1.0.0) - 2015-09-05
-                ### Packages
-                - [0.1.0](crates/one) locked to [0.1.0](https://github.com/cocogitto/cocogitto/tree/0.1.0)
-                - [0.2.0](crates/two) locked to [0.2.0](https://github.com/cocogitto/cocogitto/tree/0.2.0)
-                ### Global changes
-                #### Bug Fixes
-                - **(parser)** fix parser implementation - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
-                #### Features
-                - **(parser)** implement the changelog generator - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
-                - awesome feature - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - Paul Delafosse
-                "
-            }
+            "## [1.0.0](https://github.com/cocogitto/cocogitto/compare/0.1.0..1.0.0) - 2015-09-05
+            ### Packages
+            - [0.1.0](crates/one) locked to [0.1.0](https://github.com/cocogitto/cocogitto/tree/0.1.0)
+            - [0.2.0](crates/two) locked to [0.2.0](https://github.com/cocogitto/cocogitto/tree/0.2.0)
+            ### Global changes
+            #### Features
+            - (**parser**) implement the changelog generator - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
+            - awesome feature - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - Paul Delafosse
+            #### Bug Fixes
+            - (**parser**) fix parser implementation - ([17f7e23](https://github.com/cocogitto/cocogitto/commit/17f7e23081db15e9318aeb37529b1d473cf41cbe)) - [@oknozor](https://github.com/oknozor)
+            "
         );
 
         Ok(())
@@ -573,13 +559,11 @@ mod test {
             let version = Tag::from_str(
                 "1.0.0",
                 Some(Oid::from_str("9bb5facac5724bc81385fdd740fedbb49056da00").unwrap()),
-                None,
             )
             .unwrap();
             let from = Tag::from_str(
                 "0.1.0",
                 Some(Oid::from_str("fae3a288a1bc69b14f85a1d5fe57cee1964acd60").unwrap()),
-                None,
             )
             .unwrap();
             Release {
@@ -663,12 +647,10 @@ mod test {
                     version: OidOf::Tag(Tag::from_str(
                         "0.1.0",
                         Some(Oid::from_str("fae3a288a1bc69b14f85a1d5fe57cee1964acd60").unwrap()),
-                        None,
                     )?),
                     from: Some(OidOf::Tag(Tag::from_str(
                         "0.2.0",
                         Some(Oid::from_str("fae3a288a1bc69b14f85a1d5fe57cee1964acd60").unwrap()),
-                        None,
                     )?)),
                 },
                 PackageBumpContext {
@@ -677,12 +659,10 @@ mod test {
                     version: OidOf::Tag(Tag::from_str(
                         "0.2.0",
                         Some(Oid::from_str("fae3a288a1bc69b14f85a1d5fe57cee1964acd60").unwrap()),
-                        None,
                     )?),
                     from: Some(OidOf::Tag(Tag::from_str(
                         "0.3.0",
                         Some(Oid::from_str("fae3a288a1bc69b14f85a1d5fe57cee1964acd60").unwrap()),
-                        None,
                     )?)),
                 },
             ],
@@ -691,7 +671,7 @@ mod test {
         Ok(renderer)
     }
 
-    fn monorepo_manual_bump_rendered(renderer: Renderer) -> Result<Renderer> {
+    fn monorepo_manual_bump_renderer(renderer: Renderer) -> Result<Renderer> {
         let renderer = renderer.with_monorepo_context(MonoRepoContext {
             package_lock: true,
             packages: vec![
@@ -701,7 +681,6 @@ mod test {
                     version: OidOf::Tag(Tag::from_str(
                         "0.1.0",
                         Some(Oid::from_str("fae3a288a1bc69b14f85a1d5fe57cee1964acd60").unwrap()),
-                        None,
                     )?),
                     from: None,
                 },
@@ -711,7 +690,6 @@ mod test {
                     version: OidOf::Tag(Tag::from_str(
                         "0.2.0",
                         Some(Oid::from_str("fae3a288a1bc69b14f85a1d5fe57cee1964acd60").unwrap()),
-                        None,
                     )?),
                     from: None,
                 },
