@@ -341,6 +341,35 @@ fn bump_with_hook() -> Result<()> {
     Ok(())
 }
 
+#[sealed_test]
+#[cfg(target_os = "linux")]
+fn bump_with_hook_and_prefix() -> Result<()> {
+    // Arrange
+    git_init()?;
+    git_add(
+        r#"tag_prefix = "v"
+        pre_bump_hooks = ["touch {{version}}", "touch {{version_tag}}"]"#,
+        "cog.toml",
+    )?;
+    git_commit("chore: init")?;
+    git_tag("v1.0.0")?;
+    git_commit("feat: feature")?;
+
+    // Act
+    Command::cargo_bin("cog")?
+        .arg("bump")
+        .arg("--major")
+        // Assert
+        .assert()
+        .success();
+
+    assert_that!(Path::new("2.0.0")).exists();
+    assert_that!(Path::new("v2.0.0")).exists();
+    assert_tag_exists("v2.0.0")?;
+    assert_tag_does_not_exist("2.0.0")?;
+    Ok(())
+}
+
 #[sealed_test]
 #[cfg(target_os = "linux")]
 fn bump_with_profile_hook() -> Result<()> {
@@ -769,6 +798,7 @@ fn disable_commit_creation_with_flag_standard_ok() -> Result<()> {
 }
 
 #[sealed_test]
+#[cfg(target_os = "linux")]
 fn disable_commit_creation_with_pre_bump_hooks_standard_ok() -> Result<()> {
     git_init()?;
 
@@ -799,6 +829,34 @@ fn disable_commit_creation_with_pre_bump_hooks_standard_ok() -> Result<()> {
     Ok(())
 }
 
+#[sealed_test]
+fn override_default_commit() -> Result<()> {
+    git_init()?;
+
+    git_add(
+        indoc! {
+          r#"[commit_types]
+          feat = { changelog_title = "🌟 Features" }
+          fix = { changelog_title = "🐛 Bug Fixes" }"#
+        },
+        "cog.toml",
+    )?;
+
+    git_commit("chore: init")?;
+    git_commit("feat: feature")?;
+    git_commit("fix: fix")?;
+
+    Command::cargo_bin("cog")?
+        .arg("bump")
+        .arg("--auto")
+        .assert()
+        .success();
+
+    assert_tag_exists("0.1.0")?;
+
+    Ok(())
+}
+
 #[sealed_test]
 fn disable_commit_creation_monorepo_ok() -> Result<()> {
     let mut settings = Settings {
@@ -854,3 +912,96 @@ fn disable_commit_creation_package_ok() -> Result<()> {
 
     Ok(())
 }
+
+#[sealed_test]
+fn bump_repeatedly() -> Result<()> {
+    // Arrange
+    git_init()?;
+    git_commit("feat: first commit")?;
+
+    // Act
+    Command::cargo_bin("cog")?
+        .arg("bump")
+        .arg("--auto")
+        .arg("--build")
+        .arg("test.1")
+        .assert()
+        .success();
+
+    run_cmd!(git reset --hard HEAD^)?;
+
+    Command::cargo_bin("cog")?
+        .arg("bump")
+        .arg("--auto")
+        .arg("--build")
+        .arg("test.2")
+        .assert()
+        .success();
+
+    run_cmd!(git reset --hard HEAD^)?;
+
+    Command::cargo_bin("cog")?
+        .arg("bump")
+        .arg("--auto")
+        .arg("--build")
+        .arg("test.3")
+        .assert()
+        .success();
+
+    // Assert
+    assert_tag_exists("0.1.0+test.1")?;
+    assert_tag_exists("0.1.0+test.2")?;
+    assert_tag_exists("0.1.0+test.3")?;
+
+    Ok(())
+}
+
+#[sealed_test]
+fn bump_bug_fix() -> Result<()> {
+    // Arrange
+    git_init()?;
+    git_commit("feat: first commit")?;
+    git_tag("1.0.0")?;
+    git_commit("feat: amazing stuff")?;
+    git_commit("feat!: break everything")?;
+    git_tag("2.0.0")?;
+    run_cmd!(
+        git branch bugfix 1.0.0;
+        git switch bugfix;
+    )?;
+    git_commit("fix: important bug fix")?;
+
+    // Act
+    Command::cargo_bin("cog")?
+        .arg("bump")
+        .arg("--auto")
+        .assert()
+        .success();
+
+    // Assert
+    assert_tag_exists("1.0.1")?;
+
+    Ok(())
+}
+
+#[sealed_test]
+fn changelog_on_first_commit_with_tag_on_first_commit() -> Result<()> {
+    git_init()?;
+    git_commit("feat: init")?;
+
+    Command::cargo_bin("cog")?
+        .arg("bump")
+        .arg("--auto")
+        .arg("--disable-bump-commit")
+        .assert()
+        .success();
+
+    Command::cargo_bin("cog")?
+        .arg("changelog")
+        .arg("--at")
+        .arg("0.1.0")
+        .assert()
+        .success();
+
+    Ok(())
+}
