@@ -1,8 +1,9 @@
 use anyhow::Result;
 use assert_cmd::Command;
 use chrono::Utc;
-use cmd_lib::run_cmd;
+use cmd_lib::{run_cmd, run_fun};
 use indoc::{formatdoc, indoc};
+use itertools::Itertools;
 use pretty_assertions::assert_eq;
 use sealed_test::prelude::*;
 use std::fs;
@@ -12,6 +13,15 @@ use cocogitto::settings::Settings;
 
 use crate::helpers::*;
 
+macro_rules! assert_doc_eq {
+    ($changelog:expr, $doc:literal $($arg:tt)*) => {
+        assert_eq!(
+            $changelog.split('\n').map(|line| line.trim()).join("\n"),
+            formatdoc!($doc $($arg)*).split('\n').map(|line| line.trim()).join("\n")
+        )
+    };
+}
+
 #[test]
 fn get_changelog_range() -> Result<()> {
     // Act
@@ -29,47 +39,38 @@ fn get_changelog_range() -> Result<()> {
     let changelog = String::from_utf8_lossy(changelog.as_slice());
     let today = Utc::now().date_naive().to_string();
 
-    assert_eq!(
+    assert_doc_eq!(
         changelog.as_ref(),
-        formatdoc!(
-            "## 0.32.3 - {today}
-                #### Bug Fixes
-                - fix openssl missing in CD - (1c0d2e9) - oknozor
-                #### Documentation
-                - tag, conventional commit and license badges to readme - (da6f63d) - oknozor
-                #### Miscellaneous Chores
-                - **(version)** 0.32.3 - (0939f4c) - *oknozor*
+        "## 0.32.3 - {today}
+        #### Bug Fixes
+        - fix openssl missing in CD - (1c0d2e9) - oknozor
+        #### Documentation
+        - tag, conventional commit and license badges to readme - (da6f63d) - oknozor
 
-                - - -
+        - - -
 
-                ## 0.32.2 - {today}
-                #### Bug Fixes
-                - **(cd)** bump setup-rust-action to v1.3.3 - (5350b11) - *oknozor*
-                #### Documentation
-                - add corrections to README - (9a33516) - oknozor
-                #### Miscellaneous Chores
-                - **(version)** 0.32.2 - (ef4803b) - *oknozor*
+        ## 0.32.2 - {today}
+        #### Bug Fixes
+        - (**cd**) bump setup-rust-action to v1.3.3 - (5350b11) - *oknozor*
+        #### Documentation
+        - add corrections to README - (9a33516) - oknozor
 
-                - - -
+        - - -
 
-                ## 0.32.1 - {today}
-                #### Bug Fixes
-                - **(cd)** fix ci cross build command bin args - (7f04a98) - *oknozor*
-                #### Documentation
-                - rewritte readme completely - (b223f7b) - oknozor
-                #### Features
-                - move check edit to dedicated subcommand and fix rebase - (fc74207) - oknozor
-                - remove config commit on init existing repo - (1028d0b) - oknozor
-                #### Miscellaneous Chores
-                - **(version)** 0.32.1 - (5bcfd6f) - *oknozor*
-                - update Cargo.toml - (72bd1e4) - oknozor
-                #### Refactoring
-                - change config name to cog.toml - (d4aa61b) - oknozor
+        ## 0.32.1 - {today}
+        #### Features
+        - move check edit to dedicated subcommand and fix rebase - (fc74207) - oknozor
+        - remove config commit on init existing repo - (1028d0b) - oknozor
+        #### Bug Fixes
+        - (**cd**) fix ci cross build command bin args - (7f04a98) - *oknozor*
+        #### Documentation
+        - rewritte readme completely - (b223f7b) - oknozor
+        #### Refactoring
+        - change config name to cog.toml - (d4aa61b) - oknozor
 
 
-                ",
-            today = today
-        )
+        ",
+        today = today
     );
     Ok(())
 }
@@ -93,23 +94,21 @@ fn get_changelog_from_untagged_repo() -> Result<()> {
     let changelog = &changelog.stdout;
     let changelog = String::from_utf8_lossy(changelog.as_slice());
 
-    assert_eq!(
+    assert_doc_eq!(
         changelog.as_ref(),
-        formatdoc!(
-            "## Unreleased ({init}..{commit_three})
-                    #### Bug Fixes
-                    - bug fix - ({commit_three}) - Tom
-                    #### Features
-                    - **(taef)** feature - ({commit_two}) - Tom
-                    #### Miscellaneous Chores
-                    - init - ({init}) - Tom
+        "## Unreleased ({init}..{commit_three})
+        #### Features
+        - (**taef**) feature - ({commit_two}) - Tom
+        #### Bug Fixes
+        - bug fix - ({commit_three}) - Tom
+        #### Miscellaneous Chores
+        - init - ({init}) - Tom
 
 
-                    ",
-            init = &init[0..7],
-            commit_two = &commit_two[0..7],
-            commit_three = &commit_three[0..7]
-        )
+        ",
+        init = &init[0..7],
+        commit_two = &commit_two[0..7],
+        commit_three = &commit_three[0..7]
     );
     Ok(())
 }
@@ -135,28 +134,26 @@ fn get_changelog_from_tagged_repo() -> Result<()> {
     let changelog = String::from_utf8_lossy(changelog.as_slice());
     let today = Utc::now().date_naive().to_string();
 
-    assert_eq!(
+    assert_doc_eq!(
         changelog.as_ref(),
-        formatdoc!(
-            "## Unreleased ({commit_two}..{commit_two})
-                    #### Bug Fixes
-                    - bug fix - ({commit_two}) - Tom
+        "## Unreleased ({commit_two}..{commit_two})
+        #### Bug Fixes
+        - bug fix - ({commit_two}) - Tom
 
-                    - - -
+        - - -
 
-                    ## 1.0.0 - {today}
-                    #### Features
-                    - **(taef)** feature - ({commit_one}) - Tom
-                    #### Miscellaneous Chores
-                    - init - ({init}) - Tom
+        ## 1.0.0 - {today}
+        #### Features
+        - (**taef**) feature - ({commit_one}) - Tom
+        #### Miscellaneous Chores
+        - init - ({init}) - Tom
 
 
-                    ",
-            init = &init[0..7],
-            commit_one = &commit_one[0..7],
-            commit_two = &commit_two[0..7],
-            today = today
-        )
+        ",
+        init = &init[0..7],
+        commit_one = &commit_one[0..7],
+        commit_two = &commit_two[0..7],
+        today = today
     );
     Ok(())
 }
@@ -185,23 +182,21 @@ fn get_changelog_at_tag() -> Result<()> {
     let changelog = String::from_utf8_lossy(changelog.as_slice());
     let today = Utc::now().date_naive();
 
-    assert_eq!(
+    assert_doc_eq!(
         changelog.as_ref(),
-        formatdoc!(
-            "## 1.0.0 - {today}
-                    #### Features
-                    - **(taef)** feature - ({commit_one}) - Tom
-                    - feature 2 - ({commit_two}) - Tom
-                    #### Miscellaneous Chores
-                    - init - ({init}) - Tom
+        "## 1.0.0 - {today}
+        #### Features
+        - (**taef**) feature - ({commit_one}) - Tom
+        - feature 2 - ({commit_two}) - Tom
+        #### Miscellaneous Chores
+        - init - ({init}) - Tom
 
 
-                    ",
-            today = today,
-            init = &init[0..7],
-            commit_one = &commit_one[0..7],
-            commit_two = &commit_two[0..7]
-        )
+        ",
+        today = today,
+        init = &init[0..7],
+        commit_one = &commit_one[0..7],
+        commit_two = &commit_two[0..7]
     );
     Ok(())
 }
@@ -235,28 +230,26 @@ fn get_changelog_with_tag_prefix() -> Result<()> {
     let changelog = String::from_utf8_lossy(changelog.as_slice());
     let today = Utc::now().date_naive();
 
-    assert_eq!(
+    assert_doc_eq!(
         changelog.as_ref(),
-        formatdoc!(
-            "## Unreleased ({commit_two}..{commit_two})
-                    #### Bug Fixes
-                    - bug fix 1 - ({commit_two}) - Tom
+        "## Unreleased ({commit_two}..{commit_two})
+        #### Bug Fixes
+        - bug fix 1 - ({commit_two}) - Tom
 
-                    - - -
+        - - -
 
-                    ## v1.0.0 - {today}
-                    #### Features
-                    - feature 1 - ({commit_one}) - Tom
-                    #### Miscellaneous Chores
-                    - init - ({init}) - Tom
+        ## v1.0.0 - {today}
+        #### Features
+        - feature 1 - ({commit_one}) - Tom
+        #### Miscellaneous Chores
+        - init - ({init}) - Tom
 
 
-                    ",
-            today = today,
-            init = &init[0..7],
-            commit_one = &commit_one[0..7],
-            commit_two = &commit_two[0..7]
-        )
+        ",
+        today = today,
+        init = &init[0..7],
+        commit_one = &commit_one[0..7],
+        commit_two = &commit_two[0..7]
     );
 
     Ok(())
@@ -296,24 +289,22 @@ fn get_changelog_at_tag_prefix() -> Result<()> {
     let changelog = String::from_utf8_lossy(&changelog.stdout);
     let today = Utc::now().date_naive();
 
-    assert_eq!(
+    assert_doc_eq!(
         changelog.as_ref(),
-        formatdoc!(
-            "## v2.0.0 - {today}
-                    #### Bug Fixes
-                    - bug fix 1 - ({commit_three}) - Tom
-                    #### Features
-                    - feature 1 - ({commit_two}) - Tom
-                    #### Miscellaneous Chores
-                    - **(version)** v2.0.0 - ({commit_four}) - Tom
+        "## v2.0.0 - {today}
+        #### Features
+        - feature 1 - ({commit_two}) - Tom
+        #### Bug Fixes
+        - bug fix 1 - ({commit_three}) - Tom
+        #### Miscellaneous Chores
+        - (**version**) v2.0.0 - ({commit_four}) - Tom
 
 
-                    ",
-            today = today,
-            commit_two = &commit_two[0..7],
-            commit_three = &commit_three[0..7],
-            commit_four = &commit_four[0..7]
-        )
+        ",
+        today = today,
+        commit_two = &commit_two[0..7],
+        commit_three = &commit_three[0..7],
+        commit_four = &commit_four[0..7]
     );
     Ok(())
 }
@@ -341,36 +332,34 @@ fn get_changelog_from_tag_to_tagged_head() -> Result<()> {
     let changelog = changelog.get_output();
     let changelog = String::from_utf8_lossy(&changelog.stdout);
     let today = Utc::now().date_naive();
-    assert_eq!(
+    assert_doc_eq!(
         changelog.as_ref(),
-        formatdoc!(
-            "## 2.0.0 - {today}
-                #### Bug Fixes
-                - bug fix 1 - ({commit_four}) - Tom
-                #### Features
-                - feature 2 - ({commit_three}) - Tom
-                #### Miscellaneous Chores
-                - **(version)** 2.0.0 - ({commit_five}) - Tom
+        "## 2.0.0 - {today}
+        #### Features
+        - feature 2 - ({commit_three}) - Tom
+        #### Bug Fixes
+        - bug fix 1 - ({commit_four}) - Tom
+        #### Miscellaneous Chores
+        - (**version**) 2.0.0 - ({commit_five}) - Tom
 
-                - - -
+        - - -
 
-                ## 1.0.0 - {today}
-                #### Features
-                - feature 1 - ({commit_two}) - Tom
-                - start - ({commit_one}) - Tom
-                #### Miscellaneous Chores
-                - init - ({init}) - Tom
+        ## 1.0.0 - {today}
+        #### Features
+        - feature 1 - ({commit_two}) - Tom
+        - start - ({commit_one}) - Tom
+        #### Miscellaneous Chores
+        - init - ({init}) - Tom
 
 
-                ",
-            today = today,
-            init = &init[0..7],
-            commit_one = &commit_one[0..7],
-            commit_two = &commit_two[0..7],
-            commit_three = &commit_three[0..7],
-            commit_four = &commit_four[0..7],
-            commit_five = &commit_five[0..7],
-        )
+        ",
+        today = today,
+        init = &init[0..7],
+        commit_one = &commit_one[0..7],
+        commit_two = &commit_two[0..7],
+        commit_three = &commit_three[0..7],
+        commit_four = &commit_four[0..7],
+        commit_five = &commit_five[0..7],
     );
 
     Ok(())
@@ -400,23 +389,21 @@ fn get_changelog_is_unaffected_by_disable_changelog() -> Result<()> {
     let changelog = String::from_utf8_lossy(&changelog.stdout);
     let today = Utc::now().date_naive();
 
-    assert_eq!(
+    assert_doc_eq!(
         changelog.as_ref(),
-        formatdoc!(
-            "## 1.0.0 - {today}
-                #### Features
-                - feature 1 - ({commit_two}) - Tom
-                - start - ({commit_one}) - Tom
-                #### Miscellaneous Chores
-                - init - ({init}) - Tom
+        "## 1.0.0 - {today}
+        #### Features
+        - feature 1 - ({commit_two}) - Tom
+        - start - ({commit_one}) - Tom
+        #### Miscellaneous Chores
+        - init - ({init}) - Tom
 
 
-                ",
-            today = today,
-            init = &init[0..7],
-            commit_one = &commit_one[0..7],
-            commit_two = &commit_two[0..7],
-        )
+        ",
+        today = today,
+        init = &init[0..7],
+        commit_one = &commit_one[0..7],
+        commit_two = &commit_two[0..7],
     );
     Ok(())
 }
@@ -459,41 +446,40 @@ fn get_changelog_with_custom_template() -> Result<()> {
     let changelog = String::from_utf8_lossy(&changelog.stdout);
     let today = Utc::now().date_naive();
 
-    assert_eq!(
+    assert_doc_eq!(
         changelog.as_ref(),
-        formatdoc!(
-            "## [2.0.0](https://github.com/test/test/compare/1.0.0..2.0.0) - {today}
-            #### Bug Fixes
-            -  bug fix 1 - ([{commit_four_short}](https://github.com/test/test/commit/{commit_four})) - Tom
-            #### Features
-            -  feature 2 - ([{commit_three_short}](https://github.com/test/test/commit/{commit_three})) - Tom
-            #### Miscellaneous Chores
-            - **(version)** 2.0.0 - ([{commit_five_short}](https://github.com/test/test/commit/{commit_five})) - Tom
+        "## [2.0.0](https://github.com/test/test/compare/1.0.0..2.0.0) - {today}
+        #### Bug Fixes
+        -  bug fix 1 - ([{commit_four_short}](https://github.com/test/test/commit/{commit_four})) - Tom
+        #### Features
+        -  feature 2 - ([{commit_three_short}](https://github.com/test/test/commit/{commit_three})) - Tom
+        #### Miscellaneous Chores
+        - **(version)** 2.0.0 - ([{commit_five_short}](https://github.com/test/test/commit/{commit_five})) - Tom
 
-            - - -
+        - - -
 
-            ## [1.0.0](https://github.com/test/test/compare/{init}..1.0.0) - {today}
-            #### Features
-            -  feature 1 - ([{commit_two_short}](https://github.com/test/test/commit/{commit_two})) - Tom
-            - **(scope1)** start - ([{commit_one_short}](https://github.com/test/test/commit/{commit_one})) - Tom
-            #### Miscellaneous Chores
-            -  init - ([{init_commit}](https://github.com/test/test/commit/{init})) - Tom
+        ## [1.0.0](https://github.com/test/test/compare/{init}..1.0.0) - {today}
+        #### Features
+        -  feature 1 - ([{commit_two_short}](https://github.com/test/test/commit/{commit_two})) - Tom
+        - **(scope1)** start - ([{commit_one_short}](https://github.com/test/test/commit/{commit_one})) - Tom
+        #### Miscellaneous Chores
+        -  init - ([{init_commit}](https://github.com/test/test/commit/{init})) - Tom
 
 
-            ",
-            today = today,
-            init_commit = &init[0..7],
-            commit_one = &commit_one,
-            commit_one_short = &commit_one[0..7],
-            commit_two = &commit_two,
-            commit_two_short = &commit_two[0..7],
-            commit_three = &commit_three,
-            commit_three_short = &commit_three[0..7],
-            commit_four = &commit_four,
-            commit_four_short = &commit_four[0..7],
-            commit_five = &commit_five,
-            commit_five_short = &commit_five[0..7],
-        )
+        ",
+        today = today,
+        init = &init,
+        init_commit = &init[0..7],
+        commit_one = &commit_one,
+        commit_one_short = &commit_one[0..7],
+        commit_two = &commit_two,
+        commit_two_short = &commit_two[0..7],
+        commit_three = &commit_three,
+        commit_three_short = &commit_three[0..7],
+        commit_four = &commit_four,
+        commit_four_short = &commit_four[0..7],
+        commit_five = &commit_five,
+        commit_five_short = &commit_five[0..7],
     );
     Ok(())
 }
@@ -641,10 +627,7 @@ fn ensure_omit_from_changelog_is_honored() -> Result<()> {
 fn should_get_global_changelog() -> anyhow::Result<()> {
     // Arrange
     git_init()?;
-    run_cmd!(
-        mkdir -p packages/pkg1
-        mkdir -p packages/pkg2
-    )?;
+    mkdir(&["packages/pkg1", "packages/pkg1"])?;
 
     let cog = indoc!(
         r#"[changelog]
@@ -673,8 +656,227 @@ fn should_get_global_changelog() -> anyhow::Result<()> {
 
     Ok(())
 }
-//TODO
-/*// see: https://github.com/cocogitto/cocogitto/issues/359
+
+/// Test that the `order` configuration
+/// directive is honored if/when it is specified for
+/// a given commit type and used in a sort.
+#[sealed_test]
+fn order_from_changelog() -> Result<()> {
+    // Arrange
+    git_init()?;
+
+    let cog_toml = indoc!(
+        "[changelog]
+        remote = \"github.com\"
+        repository = \"test\"
+        owner = \"test\"
+
+        [commit_types]
+        feat = { changelog_title = \"Features\", order = 1 }
+        fix = { changelog_title = \"Bug Fixes\", order = 2 }
+        chore = { changelog_title = \"Miscellaneous Chores\", order = 3 }"
+    );
+
+    let template = indoc!(
+        "{% for order, ordered_commits in commits | sort(attribute=\"type_order\") | group_by(attribute=\"type_order\")-%}
+        #### {{ ordered_commits[0].type }}
+        {% for commit in ordered_commits -%}
+        - {{ commit.summary }}
+        {% endfor %}
+        {% endfor -%}"
+    );
+
+    let _setup = (
+        run_cmd!(echo $cog_toml > cog.toml;)?,
+        fs::read_to_string("cog.toml")?,
+        run_cmd!(echo $template > template.md;)?,
+        fs::read_to_string("template.md")?,
+        git_commit("chore: init")?,
+        git_commit("feat(scope1): start")?,
+        git_commit("feat: feature 1")?,
+        git_commit("feat: feature 2")?,
+        git_commit("fix: bug fix 1")?,
+    );
+
+    let changelog = Command::cargo_bin("cog")?
+        .arg("changelog")
+        .arg("-t")
+        .arg("template.md")
+        // Assert
+        .assert()
+        .success();
+
+    let changelog = changelog.get_output();
+    let changelog = String::from_utf8_lossy(&changelog.stdout);
+
+    assert_eq!(
+        changelog.as_ref(),
+        formatdoc!(
+            "#### Features
+            - feature 2
+            - feature 1
+            - start
+
+            #### Bug Fixes
+            - bug fix 1
+
+            #### Miscellaneous Chores
+            - init
+
+
+
+            "
+        )
+    );
+
+    let cog_toml = cog_toml.replace("order = 1", "order = 5");
+
+    run_cmd!(echo $cog_toml > cog.toml;)?;
+
+    let changelog = Command::cargo_bin("cog")?
+        .arg("changelog")
+        .arg("-t")
+        .arg("template.md")
+        // Assert
+        .assert()
+        .success();
+
+    let changelog = changelog.get_output();
+    let changelog = String::from_utf8_lossy(&changelog.stdout);
+
+    assert_eq!(
+        changelog.as_ref(),
+        formatdoc!(
+            "#### Bug Fixes
+            - bug fix 1
+
+            #### Miscellaneous Chores
+            - init
+
+            #### Features
+            - feature 2
+            - feature 1
+            - start
+
+
+
+            "
+        )
+    );
+
+    Ok(())
+}
+
+#[sealed_test]
+/// Test that the `order` configuration
+/// directive is honored if/when it is specified for
+/// a given commit type and used in a sort.
+fn group_by_type() -> Result<()> {
+    // Arrange
+    git_init()?;
+
+    let cog_toml = indoc!(
+        "[changelog]
+        remote = \"github.com\"
+        repository = \"test\"
+        owner = \"test\"
+
+        [commit_types]
+        feat = { changelog_title = \"Features\", order = 1 }
+        fix = { changelog_title = \"Bug Fixes\", order = 2 }
+        chore = { changelog_title = \"Miscellaneous Chores\", order = 3 }"
+    );
+
+    let template = indoc!(
+        "{% for value in commits | group_by_type -%}
+        #### {{ value.0 }}
+        {% for commit in value.1 -%}
+        - {{ commit.summary }}
+        {% endfor %}
+        {% endfor -%}"
+    );
+
+    let _setup = (
+        run_cmd!(echo $cog_toml > cog.toml;)?,
+        fs::read_to_string("cog.toml")?,
+        run_cmd!(echo $template > template.md;)?,
+        fs::read_to_string("template.md")?,
+        git_commit("chore: init")?,
+        git_commit("feat(scope1): start")?,
+        git_commit("feat: feature 1")?,
+        git_commit("feat: feature 2")?,
+        git_commit("fix: bug fix 1")?,
+    );
+
+    let changelog = Command::cargo_bin("cog")?
+        .arg("changelog")
+        .arg("-t")
+        .arg("template.md")
+        // Assert
+        .assert()
+        .success();
+
+    let changelog = changelog.get_output();
+    let changelog = String::from_utf8_lossy(&changelog.stdout);
+
+    assert_eq!(
+        changelog.as_ref(),
+        formatdoc!(
+            "#### Features
+            - feature 2
+            - feature 1
+            - start
+
+            #### Bug Fixes
+            - bug fix 1
+
+            #### Miscellaneous Chores
+            - init
+
+
+
+            "
+        )
+    );
+
+    let cog_toml = cog_toml.replace("order = 1", "order = 5");
+
+    run_cmd!(echo $cog_toml > cog.toml;)?;
+
+    let changelog = Command::cargo_bin("cog")?
+        .arg("changelog")
+        .arg("-t")
+        .arg("template.md")
+        // Assert
+        .assert()
+        .success();
+
+    let changelog = changelog.get_output();
+    let changelog = String::from_utf8_lossy(&changelog.stdout);
+
+    assert_eq!(
+        changelog.as_ref(),
+        formatdoc!(
+            "#### Bug Fixes
+            - bug fix 1
+
+            #### Miscellaneous Chores
+            - init
+
+            #### Features
+            - feature 2
+            - feature 1
+            - start
+
+
+
+            "
+        )
+    );
+
+    Ok(())
+}
+
 #[sealed_test]
 fn changelog_from_commit_range_should_be_the_same_as_changelog_from_tag_range() -> Result<()> {
     // Arrange
@@ -684,7 +886,6 @@ fn changelog_from_commit_range_should_be_the_same_as_changelog_from_tag_range()
     let sha_0_1 = git_commit("feat: feature 2")?;
     let _ = git_tag("0.1.0");
     git_commit("feat: feature 3")?;
-    let sha_0_2 = git_commit("feat: feature 4")?;
 
     Command::cargo_bin("cog")?
         .arg("bump")
@@ -692,6 +893,8 @@ fn changelog_from_commit_range_should_be_the_same_as_changelog_from_tag_range()
         .assert()
         .success();
 
+    let sha_0_2 = run_fun!(git log --format=%H -n 1)?;
+
     // Act
     let changelog_from_commit_range = Command::cargo_bin("cog")?
         .arg("changelog")
@@ -716,4 +919,109 @@ fn changelog_from_commit_range_should_be_the_same_as_changelog_from_tag_range()
 
     Ok(())
 }
-*/
+
+#[sealed_test]
+fn chore_commit_with_breaking_change_should_be_displayed_in_changelog() -> Result<()> {
+    // Arrange
+    git_init()?;
+    let cog_toml = indoc!(
+        "[commit_types]
+        chore = { omit_from_changelog = true }"
+    );
+    git_add(cog_toml, "cog.toml")?;
+    let _ = git_commit("chore: init")?;
+    let commit_one = git_commit("feat: feature")?;
+    git_tag("1.0.0")?;
+    let commit_two = git_commit("chore!: breaking change in chore")?;
+
+    // Act
+    let changelog = Command::cargo_bin("cog")?
+        .arg("changelog")
+        // Assert
+        .assert()
+        .success();
+
+    let changelog = changelog.get_output();
+    let changelog = &changelog.stdout;
+    let changelog = String::from_utf8_lossy(changelog.as_slice());
+    let today = Utc::now().date_naive().to_string();
+
+    assert_doc_eq!(
+        changelog.as_ref(),
+        r#"## Unreleased ({commit_two}..{commit_two})
+        #### Miscellaneous Chores
+        - <span style="background-color: #d73a49; color: white; padding: 2px 6px; border-radius: 3px; font-weight: bold; font-size: 0.85em;">BREAKING</span>breaking change in chore - ({commit_two}) - Tom
+
+        - - -
+
+        ## 1.0.0 - {today}
+        #### Features
+        - feature - ({commit_one}) - Tom
+
+
+        "#,
+        commit_one = &commit_one[0..7],
+        commit_two = &commit_two[0..7],
+        today = today
+    );
+    Ok(())
+}
+
+#[sealed_test]
+fn changelog_monorepo_multi_versions() -> Result<()> {
+    // Arrange
+    git_init()?;
+    let today = Utc::now().date_naive();
+    run_cmd!(mkdir -p zz)?;
+
+    let cog = indoc!(
+        r#"
+        tag_prefix = "v"
+
+        [packages]
+        zz = { path = "zz" }
+        "#
+    );
+
+    git_add(cog, "cog.toml")?;
+    let sha_1 = git_commit_short("chore: init")?;
+    git_add("", "zz/lib.rs")?;
+    git_add("", "main.rs")?;
+    let sha_2 = git_commit_short("feat: add implementation")?;
+
+    let sha_3 = cog_bump_auto()?;
+
+    git_add(".", "zz/lib.rs")?;
+    git_add(".", "main.rs")?;
+    let sha_4 = git_commit_short("fix: combat nasty bug")?;
+
+    let sha_5 = cog_bump_auto()?;
+
+    // Act
+    Command::cargo_bin("cog")?
+        .arg("changelog")
+        // Assert
+        .assert()
+        .success()
+        .stdout(formatdoc!(
+            "## v0.1.1 - {today}
+            #### Bug Fixes
+            - combat nasty bug - ({sha_4}) - Tom
+            #### Miscellaneous Chores
+            - (**version**) v0.1.1 - ({sha_5}) - Tom
+
+            - - -
+
+            ## v0.1.0 - {today}
+            #### Features
+            - add implementation - ({sha_2}) - Tom
+            #### Miscellaneous Chores
+            - (**version**) v0.1.0 - ({sha_3}) - Tom
+            - init - ({sha_1}) - Tom
+
+
+            "
+        ));
+
+    Ok(())
+}
